package org.ydarias.petprojects.jira.controllers

import org.springframework.stereotype.Controller
import org.springframework.web.servlet.ModelAndView
import org.springframework.web.bind.annotation.{PathVariable, RequestMethod, RequestMapping}
import org.ydarias.petprojects.jira.repository.TasksRepository
import reflect.BeanProperty
import java.util.HashMap
import org.springframework.beans.factory.annotation.Autowired
import org.ydarias.petprojects.jira.exception.InvalidTransitionException
import org.slf4j.LoggerFactory

/**
 * @author Yeray Darias Camacho <ydarias en gmail>
 */
@Controller
class TasksBoardController {

  @BeanProperty @Autowired var tasksRepository: TasksRepository = _

  private val logger = LoggerFactory.getLogger(getClass)

  @RequestMapping(value = Array("/board/{projectKey}"), method = Array(RequestMethod.GET))
  def loadBoard(@PathVariable(value = "projectKey") projectKey: String): ModelAndView = {
    val model = new HashMap[String, Object]
    model.put("openTasks", tasksRepository.listOpenTasks(projectKey))
    model.put("inProgressTasks", tasksRepository.listInProgressTasks(projectKey))
    model.put("resolvedTasks", tasksRepository.listResolvedTasks(projectKey))

    new ModelAndView("tasks/board", model)
  }

  @RequestMapping(value = Array("/task/{taskKey}/start"), method = Array(RequestMethod.POST))
  def startTask(taskKey: String): ModelAndView = {
    var redirection = "redirect:/task/update/success"
    try {
      tasksRepository.startTask(taskKey)
    } catch {
      case e: InvalidTransitionException => redirection = "redirect:/task/update/error"
      case _ => logger.warn("Something goes wrong, there is a not controlled exception")
    }

    new ModelAndView(redirection)
  }

}
