package org.ydarias.petprojects.jira.repository

import connectors.JiraConnector
import java.util.{ArrayList, List}
import org.ydarias.petprojects.jira.util.JsonProcessor
import reflect.BeanProperty
import org.ydarias.petprojects.jira.model.{TaskFactory, Task}

/**
 * @author Yeray Darias Camacho <ydarias en gmail>
 */
class TasksRepository {

  @BeanProperty var jiraConnector: JiraConnector = _

  @BeanProperty var jsonProcessor: JsonProcessor = _

  def listOpenTasks(projectKey: String): List[Task] = {
    val jsonTasksList = jiraConnector.listOpenTasks(projectKey)
    completeTaskInformation(jsonTasksList)
  }
  
  def listInProgressTasks(projectKey: String): List[Task] = {
    val jsonTasksList = jiraConnector.listInProgressTasks(projectKey)
    completeTaskInformation(jsonTasksList)
  }
  
  def listResolvedTasks(projectKey: String): List[Task] = {
    val jsonTasksList = jiraConnector.listResolvedTasks(projectKey)
    completeTaskInformation(jsonTasksList)
  }
  
  private def completeTaskInformation(jsonTasksList: String): List[Task] = {
    val tasksList = jsonProcessor.processTasksList(jsonTasksList)
    tasksList foreach {(task) =>
      val taskInfo = jiraConnector.taskInfo(task.key)
      task.setDescription(jsonProcessor.taskName(taskInfo))
    }

    toJava(tasksList)
  }

  def startTask(taskKey: String) {}

  // FIXME resolve with implicits

  private def toJava(source: scala.List[Task]): List[Task] = {
    val result = new ArrayList[Task]
    if (source != null)
      source foreach  ((task) => result.add(task))
    result
  }

}
