package org.ydarias.petprojects.jira.repository.connectors

import reflect.BeanProperty
import org.ydarias.petprojects.jira.util.jira.JQLGenerator

/**
 * @author Yeray Darias Camacho <ydarias en gmail>
 */
class JiraConnector {

  @BeanProperty var httpJiraClient: HttpJiraClient = _
  
  def listProjects(): String = {
    httpJiraClient.get("/rest/api/2.0.alpha1/project")
  }

  def listOpenTasks(projectKey: String): String = {
    val encodedQuery = JQLGenerator.instance.fromProject(projectKey).status(JiraStatus.open).encodedQuery
    httpJiraClient.get("/rest/api/2.0.alpha1/search?jql=" + encodedQuery)
  }

  def listInProgressTasks(projectKey: String): String = {
    val encodedQuery = JQLGenerator.instance.fromProject(projectKey).status(JiraStatus.inProgress).encodedQuery
    httpJiraClient.get("/rest/api/2.0.alpha1/search?jql=" + encodedQuery)
  }

  def listResolvedTasks(projectKey: String): String = {
    val encodedQuery = JQLGenerator.instance.fromProject(projectKey).status(JiraStatus.resolved).encodedQuery
    httpJiraClient.get("/rest/api/2.0.alpha1/search?jql=" + encodedQuery)
  }

  def taskInfo(taskKey: String): String = {
    httpJiraClient.get("/rest/api/2.0.alpha1/issue/" + taskKey)
  }

}

object JiraStatus {

  def open = "open"

  def inProgress = "in progress"

  def resolved = "resolved"

}