package org.ydarias.petprojects.jira.controllers

import org.mockito.Mockito._
import org.junit.runner.RunWith
import org.scalatest.junit.JUnitRunner
import org.scalatest.mock.MockitoSugar
import org.scalatest.matchers.ShouldMatchers
import org.scalatest.{FunSpec, BeforeAndAfter}
import org.ydarias.petprojects.jira.repository.ProjectsRepository

/**
 * @author Yeray Darias Camacho <ydarias en gmail>
 */
@RunWith(classOf[JUnitRunner])
class ProjectsControllerSpecs extends FunSpec with ShouldMatchers with MockitoSugar with BeforeAndAfter {

  var controller: ProjectsController = _
  
  var projectsRepositoryMock: ProjectsRepository = _

  before {
    controller = new ProjectsController()
    projectsRepositoryMock = mock[ProjectsRepository]
    controller.setProjectsRepository(projectsRepositoryMock)
  }
  
  describe("The projects controller") {

    describe("list projects response") {

      it("should contains a list of projects") {
        val response = controller.listProjects()
        response.getModelMap.containsKey("projects") should  be (true)
      }

      it("should contains a JSP direction") {
        val response = controller.listProjects()
        response.getViewName should be ("projects/list")
      }

    }

    it("should return the projects through the repository") {
      controller.listProjects()
      verify(projectsRepositoryMock).list()
    }

  }

}
