package org.ydarias.petprojects.jira.controllers

import org.mockito.Mockito._
import org.scalatest.mock.MockitoSugar
import org.scalatest.matchers.ShouldMatchers
import org.scalatest.{FunSpec, BeforeAndAfter}
import org.scalatest.junit.JUnitRunner
import org.junit.runner.RunWith
import org.ydarias.petprojects.jira.repository.TasksRepository
import org.ydarias.petprojects.jira.model.Task
import java.util.ArrayList
import org.ydarias.petprojects.jira.exception.InvalidTransitionException

/**
 * @author Yeray Darias Camacho <ydarias en gmail>
 */
@RunWith(classOf[JUnitRunner])
class TasksBoardControllerSpecs extends FunSpec with ShouldMatchers with MockitoSugar with BeforeAndAfter {

  var controller: TasksBoardController = _

  var tasksRepositoryMock: TasksRepository = _

  before {
    controller = new TasksBoardController
    tasksRepositoryMock = mock[TasksRepository]
    controller.setTasksRepository(tasksRepositoryMock)
  }

  describe("TasksBoardController") {

    describe("when load the board") {

      val projectKey = "KEY"
      val tasks = new ArrayList[Task]()

      it("should return the open tasks of the project into the model") {
        when(tasksRepositoryMock.listOpenTasks(projectKey)).thenReturn(tasks)

        val response = controller.loadBoard(projectKey)

        response.getModel.get("openTasks") should be (tasks)
      }

      it("should return the in progress tasks of the project into the model") {
        when(tasksRepositoryMock.listInProgressTasks(projectKey)).thenReturn(tasks)

        val response = controller.loadBoard(projectKey)

        response.getModel.get("inProgressTasks") should be (tasks)
      }

      it("should return the resolved tasks of the project into the model") {
        when(tasksRepositoryMock.listResolvedTasks(projectKey)).thenReturn(tasks)

        val response = controller.loadBoard(projectKey)

        response.getModel.get("resolvedTasks") should be (tasks)
      }

      it("should return the JSP direction where the board is showed") {
        val response = controller.loadBoard(projectKey)

        response.getViewName should be ("tasks/board")
      }

    }

    describe("when starts a task") {

      val taskKey = "KEY"

      it("should call tasks repository to make the transition") {
        controller.startTask(taskKey)

        verify(tasksRepositoryMock).startTask(taskKey)
      }

      it("without errors should redirect to success controller") {
        val response = controller.startTask(taskKey)

        response.getViewName should be ("redirect:/task/update/success")
      }

      it("with errors should redirect to error controller") {
        when(tasksRepositoryMock.startTask(taskKey)).thenThrow(new InvalidTransitionException)

        val response = controller.startTask(taskKey)

        response.getViewName should be ("redirect:/task/update/error")
      }

    }

  }

}
