package org.ydarias.petprojects.jira.repository

import org.mockito.Mockito._
import connectors.JiraConnector
import org.scalatest.mock.MockitoSugar
import org.scalatest.matchers.ShouldMatchers
import org.scalatest.{FunSpec, BeforeAndAfter}
import org.scalatest.junit.JUnitRunner
import org.junit.runner.RunWith
import org.ydarias.petprojects.jira.util.JsonProcessor

/**
 * @author Yeray Darias Camacho <ydarias en gmail>
 */
@RunWith(classOf[JUnitRunner])
class ProjectsRepositorySpecs extends FunSpec with ShouldMatchers with MockitoSugar with BeforeAndAfter {

  var repository: ProjectsRepository = _

  var jiraConnectorMock: JiraConnector = _

  var jsonProcessorMock: JsonProcessor = _

  before {
    repository = new ProjectsRepository
    jiraConnectorMock = mock[JiraConnector]
    repository.setJiraConnector(jiraConnectorMock)
    jsonProcessorMock = mock[JsonProcessor]
    repository.setJsonProcessor(jsonProcessorMock)
  }

  describe("A projects repository") {

    describe("when obtains the list of project") {

      it("uses Jira connector to obtain a JSON representation") {
        repository.list()

        verify(jiraConnectorMock).listProjects()
      }
      
      it("uses a JSON processor to convert JSON string into Scala instances") {
        val jsonResponse = "a response"

        when(jiraConnectorMock.listProjects()).thenReturn(jsonResponse)

        repository.list()

        verify(jsonProcessorMock).processProjectsList(jsonResponse)
      }

    }

  }

}
