package org.ydarias.petprojects.jira.repository

import org.mockito.Mockito._
import connectors.JiraConnector
import org.junit.runner.RunWith
import org.scalatest.junit.JUnitRunner
import org.scalatest.mock.MockitoSugar
import org.scalatest.matchers.ShouldMatchers
import org.scalatest.{FunSpec, BeforeAndAfter}
import org.ydarias.petprojects.jira.model.Task
import org.ydarias.petprojects.jira.util.JsonProcessor

/**
 * @author Yeray Darias Camacho <ydarias en gmail>
 */
@RunWith(classOf[JUnitRunner])
class TasksRepositorySpecs extends FunSpec with ShouldMatchers with MockitoSugar with BeforeAndAfter {

  var repository: TasksRepository = _

  var jiraConnectorMock: JiraConnector = _

  var jsonProcessorMock: JsonProcessor = _

  before {
    repository = new TasksRepository
    jiraConnectorMock = mock[JiraConnector]
    repository.setJiraConnector(jiraConnectorMock)
    jsonProcessorMock = mock[JsonProcessor]
    repository.setJsonProcessor(jsonProcessorMock)
  }

  describe("Tasks repository") {

    val projectKey = "KEY"
    val taskKey = "TASK_KEY"
    val jsonTasks = "json response"
    val task = new Task
    task.setKey(taskKey)

    describe("with open tasks") {

      it("should obtains tasks list") {
        when(jiraConnectorMock.listOpenTasks(projectKey)).thenReturn(jsonTasks)
        when(jsonProcessorMock.processTasksList(jsonTasks)).thenReturn(List(task))
        when(jiraConnectorMock.taskInfo(taskKey)).thenReturn("jsonMessage")
        when(jsonProcessorMock.taskName("jsonMessage")).thenReturn("Description open")

        val tasks = repository.listOpenTasks(projectKey)

        tasks.get(0).description should be ("Description open")
      }

    }

    it("should obtains in progress tasks") {
      when(jiraConnectorMock.listInProgressTasks(projectKey)).thenReturn(jsonTasks)
      when(jsonProcessorMock.processTasksList(jsonTasks)).thenReturn(List(task))
      when(jiraConnectorMock.taskInfo(taskKey)).thenReturn("jsonMessage")
      when(jsonProcessorMock.taskName("jsonMessage")).thenReturn("Description in progress")

      val tasks = repository.listInProgressTasks(projectKey)

      tasks.get(0).description should be ("Description in progress")
    }

    it("should obtains resolved tasks") {
      when(jiraConnectorMock.listResolvedTasks(projectKey)).thenReturn(jsonTasks)
      when(jsonProcessorMock.processTasksList(jsonTasks)).thenReturn(List(task))
      when(jiraConnectorMock.taskInfo(taskKey)).thenReturn("jsonMessage")
      when(jsonProcessorMock.taskName("jsonMessage")).thenReturn("Description closed")

      val tasks = repository.listResolvedTasks(projectKey)

      tasks.get(0).description should be ("Description closed")
    }

    describe("when start a task") {

      it("should return InvalidTransitionException on error") (pending)

    }

  }
  
}

