package org.ydarias.petprojects.jira.util

import org.scalatest.mock.MockitoSugar
import org.scalatest.matchers.ShouldMatchers
import org.scalatest.{FunSpec, BeforeAndAfter}
import org.scalatest.junit.JUnitRunner
import org.junit.runner.RunWith
import org.ydarias.petprojects.jira.model.Project

/**
 * @author Yeray Darias Camacho <ydarias en gmail>
 */
@RunWith(classOf[JUnitRunner])
class JsonProcessorSpecs extends FunSpec with ShouldMatchers with MockitoSugar with BeforeAndAfter {

  describe("JsonProcessor") {
    
    it("should transform a list of projects in JSON into a list of project instances") {
      val jsonProcessor = new JsonProcessor
      val projects = jsonProcessor.processProjectsList(JsonMessages.projectsList)

      checkProjects(projects)
    }
    
  }

  private def checkProjects(projects: List[Project]) {
    projects.length should be (2)
    projects(0).key should be ("BLACKBEAM")
    projects(1).key should be ("FUNDCLWS")
  }
  
}

object JsonMessages {
  
  def projectsList: String =
    "[{" +
      "\"self\":\"http://my.server.com:8000/rest/api/2.0.alpha1/project/BLACKBEAM\"," +
      "\"key\":\"BLACKBEAM\"," +
      "\"name\":\"Black Beam\"" +
    "}," +
    "{" +
      "\"self\":\"http://my.server.com:8000/rest/api/2.0.alpha1/project/FUNDCLWS\"," +
      "\"key\":\"FUNDCLWS\"," +
      "\"name\":\"Fundaciones Cliente WS\"" +
    "}]"
  
}
