package org.ydarias.petprojects.jira.util.jira

import org.junit.runner.RunWith
import org.scalatest.junit.JUnitRunner
import org.scalatest.mock.MockitoSugar
import org.scalatest.matchers.ShouldMatchers
import org.scalatest.{FunSpec, BeforeAndAfter}

/**
 * @author Yeray Darias Camacho <ydarias en gmail>
 */
@RunWith(classOf[JUnitRunner])
class JQLGeneratorSpecs extends FunSpec with ShouldMatchers with MockitoSugar with BeforeAndAfter {

  describe("JQLGenerator") {

    describe("should generate a query string") {

      it("for specific project") {
        val query = JQLGenerator.instance.fromProject("KEY").query
        query should be ("project = \"KEY\"")
      }

      it("for specific project and status") {
        val query = JQLGenerator.instance.fromProject("KEY").status("status").query
        query should be ("project = \"KEY\" and status = \"status\"")
      }

    }

    describe("should generate an encoded query string") {

      it("for specific project") {
        val query = JQLGenerator.instance.fromProject("KEY").encodedQuery
        query should be ("project%20%3D%20%22KEY%22")
      }

      it("for specific project and status") {
        val query = JQLGenerator.instance.fromProject("KEY").status("status").encodedQuery
        query should be ("project%20%3D%20%22KEY%22%20and%20status%20%3D%20%22status%22")
      }

    }

  }

}
